@@ -56,21 +56,21 @@ DEFAULT_CONFIG = {
         "9anime": "https://9anime.pl/",
         "allanime": "https://allanime.to/",
         "animekaizoku": "https://animekaizoku.com/",
-        "animeout": "https://animeout.xyz/",
-        "animepahe": "https://animepahe.com/",
+        "animeout": "https://www.animeout.xyz/",
+        "animepahe": "https://animepahe.ru/",
         "animeonsen": "https://animeonsen.xyz/",
         "animexin": "https://animexin.xyz/",
         "animixplay": "https://animixplay.to/",
         "animtime": "https://animtime.com/",
         "crunchyroll": "http://www.crunchyroll.com/",
         "kawaiifu": "https://kawaiifu.com/",
-        "gogoanime": "https://gogoanime.cm/",
+        "gogoanime": "https://gogoanime.bid/",
         "haho": "https://haho.moe/",
         "hentaistream": "https://hstream.moe/",
         "kamyroll_api": "https://kamyroll.herokuapp.com/",
         "marin": "https://marin.moe/",
         "twist": "https://twist.moe/",
-        "yugen": "https://yugen.to/",
+        "yugen": "https://yugenanime.ro/",
         "zoro": "https://zoro.to/",
     },
     "quality_string": "best[subtitle]/best",
